..
    Copyright (C) 2023 Graz University of Technology.

    invenio-records-global-search is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

==============================
 invenio-records-global-search
==============================

.. image:: https://github.com/tu-graz-library/invenio-records-global-search/workflows/CI/badge.svg
        :target: https://github.com/tu-graz-library/invenio-records-global-search/actions?query=workflow%3ACI

.. image:: https://img.shields.io/github/tag/tu-graz-library/invenio-records-global-search.svg
        :target: https://github.com/tu-graz-library/invenio-records-global-search/releases

.. image:: https://img.shields.io/pypi/dm/invenio-records-global-search.svg
        :target: https://pypi.python.org/pypi/invenio-records-global-search

.. image:: https://img.shields.io/github/license/tu-graz-library/invenio-records-global-search.svg
        :target: https://github.com/tu-graz-library/invenio-records-global-search/blob/master/LICENSE

Dublin Core data model for InvenioRDM

Further documentation is available on
https://invenio-records-global-search.readthedocs.io/

Tests
-----

.. code-block:: console

    pipenv run ./run-tests.sh
